==> haskell-data-bword-0.1.0.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-bword
version: 0.1.0.1
id: data-bword-0.1.0.1-IRo9XNbYSMsF9YgvmOdwoX
key: data-bword-0.1.0.1-IRo9XNbYSMsF9YgvmOdwoX
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-bword
synopsis: Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.
category: Data
abi: 12ab95b1cbd3c79a93a9786dc4fb0132
exposed: True
exposed-modules:
    Data.BinaryWord
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-bword-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-bword-0.1.0.1
hs-libraries: HSdata-bword-0.1.0.1-IRo9XNbYSMsF9YgvmOdwoX
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html: /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-bword-0.1.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-bword
version: 0.1.0.1
id: data-bword-0.1.0.1-BIS2AZE89UaKR3N10Px6Og
key: data-bword-0.1.0.1-BIS2AZE89UaKR3N10Px6Og
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-bword
synopsis: Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.
category: Data
abi: 84d21e555705eb2c06cf87d2637bf096
exposed: True
exposed-modules:
    Data.BinaryWord
import-dirs: /usr/lib/ghc-8.6.1/site-local/data-bword-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/data-bword-0.1.0.1
hs-libraries: HSdata-bword-0.1.0.1-BIS2AZE89UaKR3N10Px6Og
depends:
    base-4.12.0.0 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html: /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
